@@ -131,13 +131,13 @@ class Number(Field):
     """
 
     def __init__(
-        self,
-        *args,
-        multiplesOf=None,
-        minimum=None,
-        maximum=None,
-        exclusiveMaximum=None,
-        **kwargs,
+            self,
+            *args,
+            multiplesOf=None,
+            minimum=None,
+            maximum=None,
+            exclusiveMaximum=None,
+            **kwargs,
     ):
         self.multiplesOf = multiplesOf
         self.minimum = minimum
@@ -155,10 +155,10 @@ class Number(Field):
         if not is_number(value):
             raise TypeError(f"{err_prefix()}Expected a number")
         if (
-            isinstance(self.multiplesOf, float)
-            and int(value / self.multiplesOf) != value / self.multiplesOf
-            or isinstance(self.multiplesOf, int)
-            and value % self.multiplesOf
+                isinstance(self.multiplesOf, float)
+                and int(value / self.multiplesOf) != value / self.multiplesOf
+                or isinstance(self.multiplesOf, int)
+                and value % self.multiplesOf
         ):
             raise ValueError(
                 f"{err_prefix()}Expected a a multiple of {self.multiplesOf}"
@@ -586,11 +586,11 @@ class _DequeStruct(deque, ImmutableMixin, _IteratorProxyMixin):
     """
 
     def __init__(
-        self,
-        deq: Field = None,
-        struct_instance: Structure = None,
-        mydeque=None,
-        name: str = None,
+            self,
+            deq: Field = None,
+            struct_instance: Structure = None,
+            mydeque=None,
+            name: str = None,
     ):
         self._field_definition = deq
         self._instance = struct_instance
@@ -907,7 +907,7 @@ class Set(
         self.items = _map_to_field(items)
 
         if isinstance(self.items, TypedField) and not getattr(
-            getattr(self.items, "_ty"), "__hash__"
+                getattr(self.items, "_ty"), "__hash__"
         ):
             raise TypeError(
                 f"Set element of type {getattr(self.items, '_ty')} is not hashable"
@@ -915,6 +915,12 @@ class Set(
         super().__init__(*args, **kwargs)
         self._set_immutable(getattr(self, "_immutable", False))
 
+    @property
+    def get_type(self):
+        if not isinstance(self.items, (list, tuple)) and self.items:
+            return set[self.items.get_type]
+        return set
+
     def __set__(self, instance, value):
         cls = self.__class__._ty
         if not isinstance(value, cls):
@@ -961,7 +967,7 @@ class Map(
 
     def __init__(self, *args, items=None, **kwargs):
         if items is not None and (
-            not isinstance(items, (tuple, list)) or len(items) != 2
+                not isinstance(items, (tuple, list)) or len(items) != 2
         ):
             raise TypeError("items is expected to be a list/tuple of two fields")
         if items is None:
@@ -972,7 +978,7 @@ class Map(
                 self.items.append(_map_to_field(item))
             key_field = self.items[0]
             if isinstance(key_field, TypedField) and not getattr(
-                getattr(key_field, "_ty"), "__hash__"
+                    getattr(key_field, "_ty"), "__hash__"
             ):
                 raise TypeError(
                     f"Key field of type {key_field}, with underlying type of {getattr(key_field, '_ty')} "
@@ -1048,7 +1054,7 @@ class Array(
     _ty = list
 
     def __init__(
-        self, *args, items=None, uniqueItems=None, additionalItems=None, **kwargs
+            self, *args, items=None, uniqueItems=None, additionalItems=None, **kwargs
     ):
         """
         Constructor
@@ -1071,6 +1077,12 @@ class Array(
         super().__init__(*args, **kwargs)
         self._set_immutable(getattr(self, "_immutable", False))
 
+    @property
+    def get_type(self):
+        if not isinstance(self.items, (list, tuple)) and self.items:
+            return list[self.items.get_type]
+        return list
+
     def __set__(self, instance, value):
         verify_type_and_uniqueness(list, value, self._name, self.uniqueItems)
         self.validate_size(value, self._name)
@@ -1089,7 +1101,7 @@ class Array(
 
                 if not getattr(instance, "_skip_validation", False):
                     if len(self.items) > len(value) or (
-                        additional_properties_forbidden and len(self.items) > len(value)
+                            additional_properties_forbidden and len(self.items) > len(value)
                     ):
                         raise ValueError(
                             f"{self._name}: Got {value}; Expected an array of length {len(self.items)}"
@@ -1103,7 +1115,7 @@ class Array(
                     setattr(item, "_name", self._name + f"_{str(ind)}")
                     item.__set__(temp_st, value[ind])
                     res.append(getattr(temp_st, getattr(item, "_name")))
-                res += value[len(self.items) :]
+                res += value[len(self.items):]
                 value = res
 
         super().__set__(instance, _ListStruct(self, instance, value, self._name))
@@ -1152,7 +1164,7 @@ class Deque(
     _ty = deque
 
     def __init__(
-        self, *args, items=None, uniqueItems=None, additionalItems=None, **kwargs
+            self, *args, items=None, uniqueItems=None, additionalItems=None, **kwargs
     ):
         """
         Constructor
@@ -1193,7 +1205,7 @@ class Deque(
 
                 if not getattr(instance, "_skip_validation", False):
                     if len(self.items) > len(value) or (
-                        additional_properties_forbidden and len(self.items) > len(value)
+                            additional_properties_forbidden and len(self.items) > len(value)
                     ):
                         raise ValueError(
                             f"{self._name}: Got {value}; Expected an deque of length {len(self.items)}"
@@ -1299,6 +1311,17 @@ class Tuple(ContainNestedFieldMixin, TypedField, metaclass=_CollectionMeta):
         super().__init__(*args, **kwargs)
         self._set_immutable(getattr(self, "_immutable", False))
 
+    @property
+    def get_type(self):
+        if self.items:
+            if not isinstance(self.items, (list, tuple)):
+                return tuple[self.items.get_type]
+            if len(self.items) == 2:
+                return tuple[self.items[0].get_type, self.items[1].get_type]
+            if len(self.items) == 3:
+                return tuple[self.items[0].get_type, self.items[1].get_type, self.items[2].get_type]
+        return tuple
+
     def __set__(self, instance, value):
         verify_type_and_uniqueness(tuple, value, self._name, self.uniqueItems)
         if len(self.items) != len(value) and len(self.items) > 1:
@@ -1313,7 +1336,7 @@ class Tuple(ContainNestedFieldMixin, TypedField, metaclass=_CollectionMeta):
             setattr(item, "_name", self._name + f"_{str(ind)}")
             item.__set__(temp_st, value[ind])
             res.append(getattr(temp_st, getattr(item, "_name")))
-            res += value[len(items) :]
+            res += value[len(items):]
         value = tuple(res)
 
         super().__set__(instance, value)
